@@ -1,7 +1,7 @@
 import requests
 
 def get_poll_help(poll_id: str):
-    response = requests.get(f"https://24yl4zi1hh.execute-api.us-east-1.amazonaws.com/get/{poll_id}")
+    response = requests.get(f"https://hashapi.hackersreboot.tech/get/{poll_id}")
     if response.status_code == 200:
         return response.json()["poll"]
     return False
\ No newline at end of file
